@@ -194,39 +194,39 @@ var BuiltinFuncSignatures = map[string][]*FuncSignature{
 var BuiltinGlobalVariableTypes = map[string]ExprType{
 	// https://docs.github.com/en/actions/learn-github-actions/contexts#github-context
 	"github": NewStrictObjectType(map[string]ExprType{
-		"action":           StringType{},
-		"action_path":      StringType{},
-		"actor":            StringType{},
-		"base_ref":         StringType{},
-		"event":            NewEmptyObjectType(), // Note: Stricter type check for this payload would be possible
-		"event_name":       StringType{},
-		"event_path":       StringType{},
-		"head_ref":         StringType{},
-		"job":              StringType{},
-		"ref":              StringType{},
-		"ref_name":         StringType{},
-		"ref_protected":    StringType{},
-		"ref_type":         StringType{},
-		"repository":       StringType{},
-		"repository_owner": StringType{},
-		"run_id":           StringType{},
-		"run_number":       StringType{},
-		"run_attempt":      StringType{},
-		"server_url":       StringType{},
-		"sha":              StringType{},
-		"token":            StringType{},
-		"triggering_actor": StringType{},
-		"workflow":         StringType{},
-		"workspace":        StringType{},
-		// Below props are not documented but actually exist
+		"action":            StringType{},
+		"action_path":       StringType{},
 		"action_ref":        StringType{},
 		"action_repository": StringType{},
+		"action_status":     StringType{},
+		"actor":             StringType{},
 		"api_url":           StringType{},
+		"base_ref":          StringType{},
 		"env":               StringType{},
+		"event":             NewEmptyObjectType(), // Note: Stricter type check for this payload would be possible
+		"event_name":        StringType{},
+		"event_path":        StringType{},
 		"graphql_url":       StringType{},
+		"head_ref":          StringType{},
+		"job":               StringType{},
+		"ref":               StringType{},
+		"ref_name":          StringType{},
+		"ref_protected":     StringType{},
+		"ref_type":          StringType{},
 		"path":              StringType{},
+		"repository":        StringType{},
+		"repository_owner":  StringType{},
 		"repositoryurl":     StringType{}, // repositoryUrl
 		"retention_days":    NumberType{},
+		"run_id":            StringType{},
+		"run_number":        StringType{},
+		"run_attempt":       StringType{},
+		"server_url":        StringType{},
+		"sha":               StringType{},
+		"token":             StringType{},
+		"triggering_actor":  StringType{},
+		"workflow":          StringType{},
+		"workspace":         StringType{},
 	}),
 	// https://docs.github.com/en/actions/learn-github-actions/contexts#env-context
 	"env": NewMapObjectType(StringType{}), // env.<env_name>
@@ -240,7 +240,7 @@ var BuiltinGlobalVariableTypes = map[string]ExprType{
 			NewStrictObjectType(map[string]ExprType{
 				"id":      StringType{}, // job.services.<service id>.id
 				"network": StringType{},
-				"ports":   NewEmptyObjectType(),
+				"ports":   NewMapObjectType(StringType{}),
 			}),
 		),
 		"status": StringType{},
@@ -254,8 +254,8 @@ var BuiltinGlobalVariableTypes = map[string]ExprType{
 		"arch":       StringType{},
 		"temp":       StringType{},
 		"tool_cache": StringType{},
-		// These are not documented but actually exist
-		"workspace": StringType{},
+		"debug":      StringType{},
+		"workspace":  StringType{},
 	}),
 	// https://docs.github.com/en/actions/learn-github-actions/contexts#secrets-context
 	"secrets": NewMapObjectType(StringType{}),
